Update of /cvsroot/audacity/audacity-src/src/effects/nyquist
In directory 23jxhf1.ch3.sourceforge.com:/tmp/cvs-serv19679/effects/nyquist

Modified Files:
        Nyquist.cpp 
Log Message:
Fixed Bugs Related with Clearing tracks inside Groups (p.e. Truncate Effect 
Bug, Clear WaveTrack between Time and Label Track)
Removed some warnings.
Added Track::All enum to match all tracks. Edited TrackListOfKindIterator to 
match Track::All meaning.

Index: Nyquist.cpp
===================================================================
RCS file: /cvsroot/audacity/audacity-src/src/effects/nyquist/Nyquist.cpp,v
retrieving revision 1.78
retrieving revision 1.79
diff -u -d -r1.78 -r1.79
--- Nyquist.cpp 1 Jun 2009 05:43:40 -0000       1.78
+++ Nyquist.cpp 18 Jun 2009 00:40:06 -0000      1.79
@@ -488,8 +488,8 @@
       mProgress->Hide();
    }
 
-   this->CopyInputWaveTracks(); // Set up mOutputWaveTracks.
-   TrackListIterator iter(mOutputWaveTracks);
+   this->CopyInputTracks(); // Set up mOutputTracks.
+   TrackListIterator iter(mOutputTracks);
    mCurTrack[0] = (WaveTrack *) iter.First();
    mOutputTime = mT1 - mT0;
    mCount = 0;
@@ -561,7 +561,7 @@
       dlog.ShowModal();
    }
 
-   this->ReplaceProcessedWaveTracks(success);
+   this->ReplaceProcessedTracks(success);
 
    mDebug = false;
 


------------------------------------------------------------------------------
Crystal Reports - New Free Runtime and 30 Day Trial
Check out the new simplified licensing option that enables unlimited
royalty-free distribution of the report engine for externally facing 
server and web deployment.
http://p.sf.net/sfu/businessobjects
_______________________________________________
Audacity-cvs mailing list
[email protected]
https://lists.sourceforge.net/lists/listinfo/audacity-cvs

Reply via email to